GenerationRefusal enum

The specific reason a request was refused.

Inheritance
Available extensions

Values

unsupportedLanguage → const GenerationRefusal

The language of the prompt is not supported.

unsupportedInputImage → const GenerationRefusal

The supplied source image cannot be used.

faceTooSmall → const GenerationRefusal

A face in the source image is too small to work from.

conceptsRequirePersonIdentity → const GenerationRefusal

The concepts name a person the system cannot identify.

backgroundForbidden → const GenerationRefusal

Generation is not allowed while the app is backgrounded.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GenerationRefusal>
A constant List of the values in this enum, in order of their declaration.