GenerationUnavailableException class

Apple Intelligence is off, unsupported on this device, or not yet ready.

Inheritance

Constructors

GenerationUnavailableException(String message)
Creates the exception.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
What went wrong, as reported by the system.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited